@@ -6,6 +6,7 @@ import logging
 import subprocess
 import threading
 import time
+import socket
 
 class TestRunner(object):
 
@@ -41,9 +42,18 @@ class TestRunner(object):
         exitCode = 0
         if self.index != -1 and self.index != testIndex:
             self.logger.info("Excluding test with index " + str(testIndex))
+            self.logger.info("Excluded test " + str(testJson["name"]))
+            self.sema.release()
             return 0
+        if ("hostnames" in testJson):
+            if not (socket.gethostname() in testJson["hostnames"]):
+                self.logger.info("Excluding test because of hostname mismatch " + str(socket.gethostname()))
+                self.logger.info("Excluded test " + str(testJson["name"]))
+                self.sema.release()
+                return 0
         try:
-            self.cromwell.submitJob(self.configuration["wdl"], testJson["inputs"])
+            self.logger.info("Test name: " + str(testJson["name"]))
+            self.cromwell.submitJob(self.configuration["wdl"], testJson["inputs"], str(testIndex))
             status = "Started"
             start = time.time()
             while status != "Failed" and status != "Succeeded":
@@ -63,6 +73,8 @@ class TestRunner(object):
                         exitCode = 1
                     else:
                         bashCommand = condition["command"].replace("$file", self.cromwell.getPathToOutput(condition["file"]))
+                        if "index" in condition:
+                            bashCommand = condition["command"].replace("$file", self.cromwell.getPathToOutput(condition["file"], condition["index"]))
                         process = subprocess.Popen(bashCommand, shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
                         output, error = process.communicate()
                         output = output.decode("utf-8").strip() + error.decode("utf-8").strip()
